#[non_exhaustive]pub enum BrowserError {
BrowserNotFound {
hint: String,
},
Launch(Error),
PageCreate(Error),
Navigation {
url: Url,
source: Error,
},
NavigationTimeout {
url: Url,
timeout: Duration,
},
WaitTimeout {
what: String,
timeout: Duration,
},
Evaluation(Error),
CookieConversion(Error),
PageClosed,
Shutdown,
Protocol(Error),
}Expand description
An error produced while launching or operating a browser.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BrowserNotFound
No supported browser executable could be discovered.
Launch(Error)
Starting the browser process failed.
PageCreate(Error)
Creating a page failed.
Navigation failed before its timeout.
Navigation exceeded its configured timeout.
WaitTimeout
Waiting for a browser condition exceeded its timeout.
Evaluation(Error)
JavaScript evaluation failed.
CookieConversion(Error)
Conversion between provider and Millipede cookies failed.
PageClosed
An operation targeted a page that was already closed.
Shutdown
An operation targeted a browser pool after shutdown.
Protocol(Error)
A Chrome DevTools Protocol operation failed.
Implementations
Sourceimpl BrowserError
impl BrowserError
Sourcepub fn classify(self) -> CrawlError
pub fn classify(self) -> CrawlError
Classifies this browser failure for the crawler retry engine.