#[non_exhaustive]pub enum WaitUntil {
DomContentLoaded,
Load,
}Expand description
Browser lifecycle event awaited after navigation.
Providers map these events best-effort. A provider with weaker protocol capabilities may use the nearest available event.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DomContentLoaded
Wait until the initial HTML is parsed without waiting for subresources.
Load
Wait until the document and dependent resources report loaded.