#[non_exhaustive]pub struct BrowserResponse {
pub status: Option<StatusCode>,
pub headers: HeaderMap,
pub url: Option<Url>,
}Expand description
Navigation response metadata when the provider can expose it.
Providers are allowed to be lossy and may return no response from
BrowserPage::goto. Individual fields may also be unavailable.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.status: Option<StatusCode>Final navigation status code, when available.
headers: HeaderMapFinal navigation response headers, when available.
url: Option<Url>Final response URL, including redirects, when available.