BrowserPoolOptions

Struct BrowserPoolOptions 

#[non_exhaustive]
pub struct BrowserPoolOptions<L> { pub max_open_pages_per_browser: usize, pub retire_browser_after_page_count: u64, pub max_browsers: Option<usize>, pub page_acquire_timeout: Duration, pub launch_options: L, pub proxy: Option<ProxyConfiguration>, pub hooks: BrowserHooks, }
Configuration for a BrowserPool.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
max_open_pages_per_browser: usize

Maximum number of simultaneously open pages in one browser.

retire_browser_after_page_count: u64

Number of created pages after which a browser is retired.

max_browsers: Option<usize>

Maximum number of live or launching browsers, or None for no limit.

page_acquire_timeout: Duration

Maximum time to wait for a page, including browser launch and hook work.

launch_options: L

Provider-specific options cloned for every browser launch.

proxy: Option<ProxyConfiguration>

Optional proxy configuration resolved once per browser launch.

hooks: BrowserHooks

Browser lifecycle hooks.

Implementations

Source

impl<L: Default> BrowserPoolOptions<L>

pub fn new() -> Self

Creates options with the standard pool limits and default provider launch options.

Source

impl<L> BrowserPoolOptions<L>

pub fn with_max_open_pages_per_browser(self, value: usize) -> Self

Sets the maximum number of simultaneously open pages in one browser.

pub fn with_retire_browser_after_page_count(self, value: u64) -> Self

Sets the page count after which a browser is retired.

pub fn with_max_browsers(self, value: Option<usize>) -> Self

Sets the maximum number of live or launching browsers.

pub fn with_page_acquire_timeout(self, value: Duration) -> Self

Sets the maximum duration allowed for page acquisition.

pub fn with_launch_options(self, value: L) -> Self

Replaces the provider-specific browser launch options.

pub fn with_proxy(self, value: Option<ProxyConfiguration>) -> Self

Sets the proxy configuration used for browser launches.

pub fn with_hooks(self, value: BrowserHooks) -> Self

Replaces the browser lifecycle hooks.