SmartContext

Enum SmartContext 

#[non_exhaustive]
pub enum SmartContext { Http(HtmlContext), Browser(BrowserContext), }
A context produced by either the HTTP/HTML or browser execution path.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Http(HtmlContext)

Successful HTTP response with parsed HTML.



Browser(BrowserContext)

Browser-rendered page.

Implementations

Source

impl SmartContext

pub fn request(&self) -> &Request

Returns the request that produced this context.

pub fn enqueue(&self) -> &EnqueueLinker

Returns this context’s URL-enqueue helper.

pub fn storage(&self) -> &StorageHandle

Returns this context’s open storage handles.

pub fn crawler(&self) -> &CrawlerHandle

Returns the weak handle to the running crawler.

pub fn as_http(&self) -> Option<&HtmlContext>

Borrows the HTTP context when this request stayed on the HTTP path.

pub fn as_browser(&self) -> Option<&BrowserContext>

Borrows the browser context when this request was promoted.

pub fn is_browser(&self) -> bool

Returns whether this request executed through a browser.